=================================
antsibull-fileutils Release Notes
=================================

.. contents:: Topics

v1.0.1
======

Release Summary
---------------

Bugfix release.

Bugfixes
--------

- Remove accidentally left-in ``print()`` statement in ``antsibull_fileutils.io.write_file()`` (https://github.com/ansible-community/antsibull-fileutils/pull/5).

v1.0.0
======

Release Summary
---------------

Initial release.
